# CDK Static Wordpress

The goal of this project is to make it easy to deploy a static website, generated by [Wordpress](https://wordpress.org/)
as simple and cost-effective as possible.

It's largely inspired by
[TechToSpeech/terraform-aws-serverless-static-wordpress](https://github.com/TechToSpeech/terraform-aws-serverless-static-wordpress/),
but uses [AWS CDK](https://aws.amazon.com/cdk/) instead of Terraform.

It creates the infrastructure to launch a temporary, transient Wordpress container. You then log in and customize it
like any Wordpress site, and finally publish it as a static site fronted by a global CloudFront CDN and S3 Origin. When
you’re done you shut down the Wordpress container and it costs you almost nothing.

[WP2Static](https://wp2static.com/) is used to generate the static site from the Wordpress container.

## Quick Start

1. Install the construct:

   ```bash
   yarn add @blimmer/cdk-static-wordpress

   # or

   npm i --save @blimmer/cdk-static-wordpress
   ```

1. Instantiate a `StaticWordpress` instance a `Stack`:

   ```ts
   import { StaticWordpress } from "@blimmer/cdk-static-wordpress";
   import { Stack, StackProps } from "aws-cdk-lib";
   import { HostedZone } from "aws-cdk-lib/aws-route53";
   import { Construct } from "constructs";

   export class StaticWordpressStack extends Stack {
     constructor(scope: Construct, id: string, props?: StackProps) {
       super(scope, id, props);

       // You can create or import a hosted zone
       // See https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_route53.HostedZone.html
       const exampleHostedZone = new HostedZone(this, "ExampleHostedZone", {
         zoneName: "example.com",
       });
       new StaticWordpress(this, "StaticWordpress", {
         fullyQualifiedSiteName: "blog.example.com",
         hostedZone: exampleHostedZone,
         wordpressAdminProps: {
           email: "me@example.com",
         },
       });
     }
   }
   ```

1. Deploy with the [`cdk deploy` command](https://docs.aws.amazon.com/cdk/v2/guide/cli.html#cli-deploy)
1. Once the deployment completes, visit the Wordpress console at `admin-<fullyQualifiedSiteName>`. E.g., if your static
   site is `blog.example.com`, visit `admin-blog.example.com/wp-admin`.
1. Customize Wordpress as you see fit, create posts, etc.
1. When you're ready to deploy your static site, trigger WP2Static.

   ![](https://github.com/blimmer/cdk-static-wordpress/assets/630449/598ecdd4-ffb6-4381-bd0e-50564622f3c3)

1. Visit your static site (e.g., `blog.example.com`) once WP2Static completes.
1. (optional) Shut down the Wordpress container to save money.

   ```ts
   new StaticWordpress(this, "StaticWordpress", {
     fullyQualifiedSiteName: "blog.example.com",
     hostedZone: exampleHostedZone,
     wordpressAdminProps: {
       email: "me@example.com",
       run: false, // <-- Shut down the container after deployment
     },
   });
   ```

## Architecture

TODO

# API Reference <a name="API Reference" id="api-reference"></a>

## Constructs <a name="Constructs" id="Constructs"></a>

### EcsTask <a name="EcsTask" id="@blimmer/cdk-static-wordpress.EcsTask"></a>

#### Initializers <a name="Initializers" id="@blimmer/cdk-static-wordpress.EcsTask.Initializer"></a>

```typescript
import { EcsTask } from '@blimmer/cdk-static-wordpress'

new EcsTask(scope: Construct, id: string, props: EcsTaskProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@blimmer/cdk-static-wordpress.EcsTask.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | *No description.* |
| <code><a href="#@blimmer/cdk-static-wordpress.EcsTask.Initializer.parameter.id">id</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@blimmer/cdk-static-wordpress.EcsTask.Initializer.parameter.props">props</a></code> | <code><a href="#@blimmer/cdk-static-wordpress.EcsTaskProps">EcsTaskProps</a></code> | *No description.* |

---

##### `scope`<sup>Required</sup> <a name="scope" id="@blimmer/cdk-static-wordpress.EcsTask.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

---

##### `id`<sup>Required</sup> <a name="id" id="@blimmer/cdk-static-wordpress.EcsTask.Initializer.parameter.id"></a>

- *Type:* string

---

##### `props`<sup>Required</sup> <a name="props" id="@blimmer/cdk-static-wordpress.EcsTask.Initializer.parameter.props"></a>

- *Type:* <a href="#@blimmer/cdk-static-wordpress.EcsTaskProps">EcsTaskProps</a>

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@blimmer/cdk-static-wordpress.EcsTask.toString">toString</a></code> | Returns a string representation of this construct. |

---

##### `toString` <a name="toString" id="@blimmer/cdk-static-wordpress.EcsTask.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@blimmer/cdk-static-wordpress.EcsTask.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="@blimmer/cdk-static-wordpress.EcsTask.isConstruct"></a>

```typescript
import { EcsTask } from '@blimmer/cdk-static-wordpress'

EcsTask.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="@blimmer/cdk-static-wordpress.EcsTask.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@blimmer/cdk-static-wordpress.EcsTask.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#@blimmer/cdk-static-wordpress.EcsTask.property.databaseCluster">databaseCluster</a></code> | <code>aws-cdk-lib.aws_rds.ServerlessCluster</code> | *No description.* |
| <code><a href="#@blimmer/cdk-static-wordpress.EcsTask.property.fargateService">fargateService</a></code> | <code>aws-cdk-lib.aws_ecs.FargateService</code> | *No description.* |
| <code><a href="#@blimmer/cdk-static-wordpress.EcsTask.property.fileSystem">fileSystem</a></code> | <code>aws-cdk-lib.aws_efs.FileSystem</code> | *No description.* |
| <code><a href="#@blimmer/cdk-static-wordpress.EcsTask.property.taskDefinition">taskDefinition</a></code> | <code>aws-cdk-lib.aws_ecs.FargateTaskDefinition</code> | *No description.* |

---

##### `node`<sup>Required</sup> <a name="node" id="@blimmer/cdk-static-wordpress.EcsTask.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `databaseCluster`<sup>Required</sup> <a name="databaseCluster" id="@blimmer/cdk-static-wordpress.EcsTask.property.databaseCluster"></a>

```typescript
public readonly databaseCluster: ServerlessCluster;
```

- *Type:* aws-cdk-lib.aws_rds.ServerlessCluster

---

##### `fargateService`<sup>Required</sup> <a name="fargateService" id="@blimmer/cdk-static-wordpress.EcsTask.property.fargateService"></a>

```typescript
public readonly fargateService: FargateService;
```

- *Type:* aws-cdk-lib.aws_ecs.FargateService

---

##### `fileSystem`<sup>Required</sup> <a name="fileSystem" id="@blimmer/cdk-static-wordpress.EcsTask.property.fileSystem"></a>

```typescript
public readonly fileSystem: FileSystem;
```

- *Type:* aws-cdk-lib.aws_efs.FileSystem

---

##### `taskDefinition`<sup>Required</sup> <a name="taskDefinition" id="@blimmer/cdk-static-wordpress.EcsTask.property.taskDefinition"></a>

```typescript
public readonly taskDefinition: FargateTaskDefinition;
```

- *Type:* aws-cdk-lib.aws_ecs.FargateTaskDefinition

---


### StaticHosting <a name="StaticHosting" id="@blimmer/cdk-static-wordpress.StaticHosting"></a>

#### Initializers <a name="Initializers" id="@blimmer/cdk-static-wordpress.StaticHosting.Initializer"></a>

```typescript
import { StaticHosting } from '@blimmer/cdk-static-wordpress'

new StaticHosting(scope: Construct, id: string, props: StaticHostingProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@blimmer/cdk-static-wordpress.StaticHosting.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | *No description.* |
| <code><a href="#@blimmer/cdk-static-wordpress.StaticHosting.Initializer.parameter.id">id</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@blimmer/cdk-static-wordpress.StaticHosting.Initializer.parameter.props">props</a></code> | <code><a href="#@blimmer/cdk-static-wordpress.StaticHostingProps">StaticHostingProps</a></code> | *No description.* |

---

##### `scope`<sup>Required</sup> <a name="scope" id="@blimmer/cdk-static-wordpress.StaticHosting.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

---

##### `id`<sup>Required</sup> <a name="id" id="@blimmer/cdk-static-wordpress.StaticHosting.Initializer.parameter.id"></a>

- *Type:* string

---

##### `props`<sup>Required</sup> <a name="props" id="@blimmer/cdk-static-wordpress.StaticHosting.Initializer.parameter.props"></a>

- *Type:* <a href="#@blimmer/cdk-static-wordpress.StaticHostingProps">StaticHostingProps</a>

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@blimmer/cdk-static-wordpress.StaticHosting.toString">toString</a></code> | Returns a string representation of this construct. |

---

##### `toString` <a name="toString" id="@blimmer/cdk-static-wordpress.StaticHosting.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@blimmer/cdk-static-wordpress.StaticHosting.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="@blimmer/cdk-static-wordpress.StaticHosting.isConstruct"></a>

```typescript
import { StaticHosting } from '@blimmer/cdk-static-wordpress'

StaticHosting.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="@blimmer/cdk-static-wordpress.StaticHosting.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@blimmer/cdk-static-wordpress.StaticHosting.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#@blimmer/cdk-static-wordpress.StaticHosting.property.bucket">bucket</a></code> | <code>aws-cdk-lib.aws_s3.Bucket</code> | *No description.* |
| <code><a href="#@blimmer/cdk-static-wordpress.StaticHosting.property.distribution">distribution</a></code> | <code>aws-cdk-lib.aws_cloudfront.Distribution</code> | *No description.* |

---

##### `node`<sup>Required</sup> <a name="node" id="@blimmer/cdk-static-wordpress.StaticHosting.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `bucket`<sup>Required</sup> <a name="bucket" id="@blimmer/cdk-static-wordpress.StaticHosting.property.bucket"></a>

```typescript
public readonly bucket: Bucket;
```

- *Type:* aws-cdk-lib.aws_s3.Bucket

---

##### `distribution`<sup>Required</sup> <a name="distribution" id="@blimmer/cdk-static-wordpress.StaticHosting.property.distribution"></a>

```typescript
public readonly distribution: Distribution;
```

- *Type:* aws-cdk-lib.aws_cloudfront.Distribution

---


### StaticWordpress <a name="StaticWordpress" id="@blimmer/cdk-static-wordpress.StaticWordpress"></a>

#### Initializers <a name="Initializers" id="@blimmer/cdk-static-wordpress.StaticWordpress.Initializer"></a>

```typescript
import { StaticWordpress } from '@blimmer/cdk-static-wordpress'

new StaticWordpress(scope: Construct, id: string, props: StaticWordpressProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@blimmer/cdk-static-wordpress.StaticWordpress.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | *No description.* |
| <code><a href="#@blimmer/cdk-static-wordpress.StaticWordpress.Initializer.parameter.id">id</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@blimmer/cdk-static-wordpress.StaticWordpress.Initializer.parameter.props">props</a></code> | <code><a href="#@blimmer/cdk-static-wordpress.StaticWordpressProps">StaticWordpressProps</a></code> | *No description.* |

---

##### `scope`<sup>Required</sup> <a name="scope" id="@blimmer/cdk-static-wordpress.StaticWordpress.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

---

##### `id`<sup>Required</sup> <a name="id" id="@blimmer/cdk-static-wordpress.StaticWordpress.Initializer.parameter.id"></a>

- *Type:* string

---

##### `props`<sup>Required</sup> <a name="props" id="@blimmer/cdk-static-wordpress.StaticWordpress.Initializer.parameter.props"></a>

- *Type:* <a href="#@blimmer/cdk-static-wordpress.StaticWordpressProps">StaticWordpressProps</a>

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@blimmer/cdk-static-wordpress.StaticWordpress.toString">toString</a></code> | Returns a string representation of this construct. |

---

##### `toString` <a name="toString" id="@blimmer/cdk-static-wordpress.StaticWordpress.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@blimmer/cdk-static-wordpress.StaticWordpress.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="@blimmer/cdk-static-wordpress.StaticWordpress.isConstruct"></a>

```typescript
import { StaticWordpress } from '@blimmer/cdk-static-wordpress'

StaticWordpress.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="@blimmer/cdk-static-wordpress.StaticWordpress.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@blimmer/cdk-static-wordpress.StaticWordpress.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#@blimmer/cdk-static-wordpress.StaticWordpress.property.ecsTask">ecsTask</a></code> | <code><a href="#@blimmer/cdk-static-wordpress.EcsTask">EcsTask</a></code> | *No description.* |
| <code><a href="#@blimmer/cdk-static-wordpress.StaticWordpress.property.staticHosting">staticHosting</a></code> | <code><a href="#@blimmer/cdk-static-wordpress.StaticHosting">StaticHosting</a></code> | *No description.* |
| <code><a href="#@blimmer/cdk-static-wordpress.StaticWordpress.property.wordpressDockerImage">wordpressDockerImage</a></code> | <code><a href="#@blimmer/cdk-static-wordpress.WordpressDockerImage">WordpressDockerImage</a></code> | *No description.* |

---

##### `node`<sup>Required</sup> <a name="node" id="@blimmer/cdk-static-wordpress.StaticWordpress.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `ecsTask`<sup>Required</sup> <a name="ecsTask" id="@blimmer/cdk-static-wordpress.StaticWordpress.property.ecsTask"></a>

```typescript
public readonly ecsTask: EcsTask;
```

- *Type:* <a href="#@blimmer/cdk-static-wordpress.EcsTask">EcsTask</a>

---

##### `staticHosting`<sup>Required</sup> <a name="staticHosting" id="@blimmer/cdk-static-wordpress.StaticWordpress.property.staticHosting"></a>

```typescript
public readonly staticHosting: StaticHosting;
```

- *Type:* <a href="#@blimmer/cdk-static-wordpress.StaticHosting">StaticHosting</a>

---

##### `wordpressDockerImage`<sup>Required</sup> <a name="wordpressDockerImage" id="@blimmer/cdk-static-wordpress.StaticWordpress.property.wordpressDockerImage"></a>

```typescript
public readonly wordpressDockerImage: WordpressDockerImage;
```

- *Type:* <a href="#@blimmer/cdk-static-wordpress.WordpressDockerImage">WordpressDockerImage</a>

---


### WordpressDockerImage <a name="WordpressDockerImage" id="@blimmer/cdk-static-wordpress.WordpressDockerImage"></a>

#### Initializers <a name="Initializers" id="@blimmer/cdk-static-wordpress.WordpressDockerImage.Initializer"></a>

```typescript
import { WordpressDockerImage } from '@blimmer/cdk-static-wordpress'

new WordpressDockerImage(scope: Construct, id: string, props?: WordpressDockerImageProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@blimmer/cdk-static-wordpress.WordpressDockerImage.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | *No description.* |
| <code><a href="#@blimmer/cdk-static-wordpress.WordpressDockerImage.Initializer.parameter.id">id</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@blimmer/cdk-static-wordpress.WordpressDockerImage.Initializer.parameter.props">props</a></code> | <code><a href="#@blimmer/cdk-static-wordpress.WordpressDockerImageProps">WordpressDockerImageProps</a></code> | *No description.* |

---

##### `scope`<sup>Required</sup> <a name="scope" id="@blimmer/cdk-static-wordpress.WordpressDockerImage.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

---

##### `id`<sup>Required</sup> <a name="id" id="@blimmer/cdk-static-wordpress.WordpressDockerImage.Initializer.parameter.id"></a>

- *Type:* string

---

##### `props`<sup>Optional</sup> <a name="props" id="@blimmer/cdk-static-wordpress.WordpressDockerImage.Initializer.parameter.props"></a>

- *Type:* <a href="#@blimmer/cdk-static-wordpress.WordpressDockerImageProps">WordpressDockerImageProps</a>

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@blimmer/cdk-static-wordpress.WordpressDockerImage.toString">toString</a></code> | Returns a string representation of this construct. |

---

##### `toString` <a name="toString" id="@blimmer/cdk-static-wordpress.WordpressDockerImage.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@blimmer/cdk-static-wordpress.WordpressDockerImage.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="@blimmer/cdk-static-wordpress.WordpressDockerImage.isConstruct"></a>

```typescript
import { WordpressDockerImage } from '@blimmer/cdk-static-wordpress'

WordpressDockerImage.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="@blimmer/cdk-static-wordpress.WordpressDockerImage.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@blimmer/cdk-static-wordpress.WordpressDockerImage.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#@blimmer/cdk-static-wordpress.WordpressDockerImage.property.containerCpu">containerCpu</a></code> | <code>number</code> | *No description.* |
| <code><a href="#@blimmer/cdk-static-wordpress.WordpressDockerImage.property.containerMemory">containerMemory</a></code> | <code>number</code> | *No description.* |
| <code><a href="#@blimmer/cdk-static-wordpress.WordpressDockerImage.property.dockerImageAsset">dockerImageAsset</a></code> | <code>aws-cdk-lib.aws_ecr_assets.DockerImageAsset</code> | *No description.* |
| <code><a href="#@blimmer/cdk-static-wordpress.WordpressDockerImage.property.wordpressMemoryLimit">wordpressMemoryLimit</a></code> | <code>string</code> | *No description.* |

---

##### `node`<sup>Required</sup> <a name="node" id="@blimmer/cdk-static-wordpress.WordpressDockerImage.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `containerCpu`<sup>Required</sup> <a name="containerCpu" id="@blimmer/cdk-static-wordpress.WordpressDockerImage.property.containerCpu"></a>

```typescript
public readonly containerCpu: number;
```

- *Type:* number

---

##### `containerMemory`<sup>Required</sup> <a name="containerMemory" id="@blimmer/cdk-static-wordpress.WordpressDockerImage.property.containerMemory"></a>

```typescript
public readonly containerMemory: number;
```

- *Type:* number

---

##### `dockerImageAsset`<sup>Required</sup> <a name="dockerImageAsset" id="@blimmer/cdk-static-wordpress.WordpressDockerImage.property.dockerImageAsset"></a>

```typescript
public readonly dockerImageAsset: DockerImageAsset;
```

- *Type:* aws-cdk-lib.aws_ecr_assets.DockerImageAsset

---

##### `wordpressMemoryLimit`<sup>Required</sup> <a name="wordpressMemoryLimit" id="@blimmer/cdk-static-wordpress.WordpressDockerImage.property.wordpressMemoryLimit"></a>

```typescript
public readonly wordpressMemoryLimit: string;
```

- *Type:* string

---


## Structs <a name="Structs" id="Structs"></a>

### CloudFrontDistributionConfig <a name="CloudFrontDistributionConfig" id="@blimmer/cdk-static-wordpress.CloudFrontDistributionConfig"></a>

#### Initializer <a name="Initializer" id="@blimmer/cdk-static-wordpress.CloudFrontDistributionConfig.Initializer"></a>

```typescript
import { CloudFrontDistributionConfig } from '@blimmer/cdk-static-wordpress'

const cloudFrontDistributionConfig: CloudFrontDistributionConfig = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@blimmer/cdk-static-wordpress.CloudFrontDistributionConfig.property.functionAssociations">functionAssociations</a></code> | <code>aws-cdk-lib.aws_cloudfront.FunctionAssociation[]</code> | WARNING: you should not probably not use this property. |
| <code><a href="#@blimmer/cdk-static-wordpress.CloudFrontDistributionConfig.property.priceClass">priceClass</a></code> | <code>aws-cdk-lib.aws_cloudfront.PriceClass</code> | The PriceClass to use for the CloudFront distribution. |

---

##### `functionAssociations`<sup>Optional</sup> <a name="functionAssociations" id="@blimmer/cdk-static-wordpress.CloudFrontDistributionConfig.property.functionAssociations"></a>

```typescript
public readonly functionAssociations: FunctionAssociation[];
```

- *Type:* aws-cdk-lib.aws_cloudfront.FunctionAssociation[]

WARNING: you should not probably not use this property.

The author is using this for an advanced workaround
on one of his sites.

---

##### `priceClass`<sup>Optional</sup> <a name="priceClass" id="@blimmer/cdk-static-wordpress.CloudFrontDistributionConfig.property.priceClass"></a>

```typescript
public readonly priceClass: PriceClass;
```

- *Type:* aws-cdk-lib.aws_cloudfront.PriceClass
- *Default:* PriceClass.PRICE_CLASS_ALL

The PriceClass to use for the CloudFront distribution.

See
https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/PriceClass.html

---

### EcsTaskProps <a name="EcsTaskProps" id="@blimmer/cdk-static-wordpress.EcsTaskProps"></a>

#### Initializer <a name="Initializer" id="@blimmer/cdk-static-wordpress.EcsTaskProps.Initializer"></a>

```typescript
import { EcsTaskProps } from '@blimmer/cdk-static-wordpress'

const ecsTaskProps: EcsTaskProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@blimmer/cdk-static-wordpress.EcsTaskProps.property.fullyQualifiedSiteName">fullyQualifiedSiteName</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@blimmer/cdk-static-wordpress.EcsTaskProps.property.hostedZone">hostedZone</a></code> | <code>aws-cdk-lib.aws_route53.IHostedZone</code> | *No description.* |
| <code><a href="#@blimmer/cdk-static-wordpress.EcsTaskProps.property.siteId">siteId</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@blimmer/cdk-static-wordpress.EcsTaskProps.property.staticHosting">staticHosting</a></code> | <code><a href="#@blimmer/cdk-static-wordpress.StaticHosting">StaticHosting</a></code> | *No description.* |
| <code><a href="#@blimmer/cdk-static-wordpress.EcsTaskProps.property.wordpressAdminProps">wordpressAdminProps</a></code> | <code><a href="#@blimmer/cdk-static-wordpress.WordpressAdminProps">WordpressAdminProps</a></code> | *No description.* |
| <code><a href="#@blimmer/cdk-static-wordpress.EcsTaskProps.property.wordpressDockerImage">wordpressDockerImage</a></code> | <code><a href="#@blimmer/cdk-static-wordpress.WordpressDockerImage">WordpressDockerImage</a></code> | *No description.* |
| <code><a href="#@blimmer/cdk-static-wordpress.EcsTaskProps.property.ecsCluster">ecsCluster</a></code> | <code>aws-cdk-lib.aws_ecs.ICluster</code> | *No description.* |
| <code><a href="#@blimmer/cdk-static-wordpress.EcsTaskProps.property.vpc">vpc</a></code> | <code>aws-cdk-lib.aws_ec2.IVpc</code> | *No description.* |
| <code><a href="#@blimmer/cdk-static-wordpress.EcsTaskProps.property.wordpressDatabaseProps">wordpressDatabaseProps</a></code> | <code><a href="#@blimmer/cdk-static-wordpress.WordpressDatabaseProps">WordpressDatabaseProps</a></code> | *No description.* |

---

##### `fullyQualifiedSiteName`<sup>Required</sup> <a name="fullyQualifiedSiteName" id="@blimmer/cdk-static-wordpress.EcsTaskProps.property.fullyQualifiedSiteName"></a>

```typescript
public readonly fullyQualifiedSiteName: string;
```

- *Type:* string

---

##### `hostedZone`<sup>Required</sup> <a name="hostedZone" id="@blimmer/cdk-static-wordpress.EcsTaskProps.property.hostedZone"></a>

```typescript
public readonly hostedZone: IHostedZone;
```

- *Type:* aws-cdk-lib.aws_route53.IHostedZone

---

##### `siteId`<sup>Required</sup> <a name="siteId" id="@blimmer/cdk-static-wordpress.EcsTaskProps.property.siteId"></a>

```typescript
public readonly siteId: string;
```

- *Type:* string

---

##### `staticHosting`<sup>Required</sup> <a name="staticHosting" id="@blimmer/cdk-static-wordpress.EcsTaskProps.property.staticHosting"></a>

```typescript
public readonly staticHosting: StaticHosting;
```

- *Type:* <a href="#@blimmer/cdk-static-wordpress.StaticHosting">StaticHosting</a>

---

##### `wordpressAdminProps`<sup>Required</sup> <a name="wordpressAdminProps" id="@blimmer/cdk-static-wordpress.EcsTaskProps.property.wordpressAdminProps"></a>

```typescript
public readonly wordpressAdminProps: WordpressAdminProps;
```

- *Type:* <a href="#@blimmer/cdk-static-wordpress.WordpressAdminProps">WordpressAdminProps</a>

---

##### `wordpressDockerImage`<sup>Required</sup> <a name="wordpressDockerImage" id="@blimmer/cdk-static-wordpress.EcsTaskProps.property.wordpressDockerImage"></a>

```typescript
public readonly wordpressDockerImage: WordpressDockerImage;
```

- *Type:* <a href="#@blimmer/cdk-static-wordpress.WordpressDockerImage">WordpressDockerImage</a>

---

##### `ecsCluster`<sup>Optional</sup> <a name="ecsCluster" id="@blimmer/cdk-static-wordpress.EcsTaskProps.property.ecsCluster"></a>

```typescript
public readonly ecsCluster: ICluster;
```

- *Type:* aws-cdk-lib.aws_ecs.ICluster

---

##### `vpc`<sup>Optional</sup> <a name="vpc" id="@blimmer/cdk-static-wordpress.EcsTaskProps.property.vpc"></a>

```typescript
public readonly vpc: IVpc;
```

- *Type:* aws-cdk-lib.aws_ec2.IVpc

---

##### `wordpressDatabaseProps`<sup>Optional</sup> <a name="wordpressDatabaseProps" id="@blimmer/cdk-static-wordpress.EcsTaskProps.property.wordpressDatabaseProps"></a>

```typescript
public readonly wordpressDatabaseProps: WordpressDatabaseProps;
```

- *Type:* <a href="#@blimmer/cdk-static-wordpress.WordpressDatabaseProps">WordpressDatabaseProps</a>

---

### StaticHostingProps <a name="StaticHostingProps" id="@blimmer/cdk-static-wordpress.StaticHostingProps"></a>

#### Initializer <a name="Initializer" id="@blimmer/cdk-static-wordpress.StaticHostingProps.Initializer"></a>

```typescript
import { StaticHostingProps } from '@blimmer/cdk-static-wordpress'

const staticHostingProps: StaticHostingProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@blimmer/cdk-static-wordpress.StaticHostingProps.property.fullyQualifiedSiteName">fullyQualifiedSiteName</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@blimmer/cdk-static-wordpress.StaticHostingProps.property.hostedZone">hostedZone</a></code> | <code>aws-cdk-lib.aws_route53.IHostedZone</code> | *No description.* |
| <code><a href="#@blimmer/cdk-static-wordpress.StaticHostingProps.property.siteId">siteId</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@blimmer/cdk-static-wordpress.StaticHostingProps.property.cloudFrontDistributionConfig">cloudFrontDistributionConfig</a></code> | <code><a href="#@blimmer/cdk-static-wordpress.CloudFrontDistributionConfig">CloudFrontDistributionConfig</a></code> | *No description.* |
| <code><a href="#@blimmer/cdk-static-wordpress.StaticHostingProps.property.redirects">redirects</a></code> | <code>{[ key: string ]: string}</code> | *No description.* |

---

##### `fullyQualifiedSiteName`<sup>Required</sup> <a name="fullyQualifiedSiteName" id="@blimmer/cdk-static-wordpress.StaticHostingProps.property.fullyQualifiedSiteName"></a>

```typescript
public readonly fullyQualifiedSiteName: string;
```

- *Type:* string

---

##### `hostedZone`<sup>Required</sup> <a name="hostedZone" id="@blimmer/cdk-static-wordpress.StaticHostingProps.property.hostedZone"></a>

```typescript
public readonly hostedZone: IHostedZone;
```

- *Type:* aws-cdk-lib.aws_route53.IHostedZone

---

##### `siteId`<sup>Required</sup> <a name="siteId" id="@blimmer/cdk-static-wordpress.StaticHostingProps.property.siteId"></a>

```typescript
public readonly siteId: string;
```

- *Type:* string

---

##### `cloudFrontDistributionConfig`<sup>Optional</sup> <a name="cloudFrontDistributionConfig" id="@blimmer/cdk-static-wordpress.StaticHostingProps.property.cloudFrontDistributionConfig"></a>

```typescript
public readonly cloudFrontDistributionConfig: CloudFrontDistributionConfig;
```

- *Type:* <a href="#@blimmer/cdk-static-wordpress.CloudFrontDistributionConfig">CloudFrontDistributionConfig</a>

---

##### `redirects`<sup>Optional</sup> <a name="redirects" id="@blimmer/cdk-static-wordpress.StaticHostingProps.property.redirects"></a>

```typescript
public readonly redirects: {[ key: string ]: string};
```

- *Type:* {[ key: string ]: string}

---

### StaticWordpressProps <a name="StaticWordpressProps" id="@blimmer/cdk-static-wordpress.StaticWordpressProps"></a>

#### Initializer <a name="Initializer" id="@blimmer/cdk-static-wordpress.StaticWordpressProps.Initializer"></a>

```typescript
import { StaticWordpressProps } from '@blimmer/cdk-static-wordpress'

const staticWordpressProps: StaticWordpressProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@blimmer/cdk-static-wordpress.StaticWordpressProps.property.fullyQualifiedSiteName">fullyQualifiedSiteName</a></code> | <code>string</code> | The fully qualified site name (e.g., myblog.com or subdomain.myblog.com). |
| <code><a href="#@blimmer/cdk-static-wordpress.StaticWordpressProps.property.hostedZone">hostedZone</a></code> | <code>aws-cdk-lib.aws_route53.IHostedZone</code> | The HostedZone to use to create DNS entries for the site. |
| <code><a href="#@blimmer/cdk-static-wordpress.StaticWordpressProps.property.wordpressAdminProps">wordpressAdminProps</a></code> | <code><a href="#@blimmer/cdk-static-wordpress.WordpressAdminProps">WordpressAdminProps</a></code> | *No description.* |
| <code><a href="#@blimmer/cdk-static-wordpress.StaticWordpressProps.property.cloudFrontDistributionConfig">cloudFrontDistributionConfig</a></code> | <code><a href="#@blimmer/cdk-static-wordpress.CloudFrontDistributionConfig">CloudFrontDistributionConfig</a></code> | *No description.* |
| <code><a href="#@blimmer/cdk-static-wordpress.StaticWordpressProps.property.ecsCluster">ecsCluster</a></code> | <code>aws-cdk-lib.aws_ecs.ICluster</code> | The ECS cluster for the Wordpress admin site. |
| <code><a href="#@blimmer/cdk-static-wordpress.StaticWordpressProps.property.siteId">siteId</a></code> | <code>string</code> | An ID to use throughout this construct to identify resources. Any non-word characters will be replaced with dashes. |
| <code><a href="#@blimmer/cdk-static-wordpress.StaticWordpressProps.property.vpc">vpc</a></code> | <code>aws-cdk-lib.aws_ec2.IVpc</code> | The VPC assigned to the `ecsCluster`. |
| <code><a href="#@blimmer/cdk-static-wordpress.StaticWordpressProps.property.wordpressDatabaseProps">wordpressDatabaseProps</a></code> | <code><a href="#@blimmer/cdk-static-wordpress.WordpressDatabaseProps">WordpressDatabaseProps</a></code> | *No description.* |
| <code><a href="#@blimmer/cdk-static-wordpress.StaticWordpressProps.property.wordpressDockerImageProps">wordpressDockerImageProps</a></code> | <code><a href="#@blimmer/cdk-static-wordpress.WordpressDockerImageProps">WordpressDockerImageProps</a></code> | *No description.* |

---

##### `fullyQualifiedSiteName`<sup>Required</sup> <a name="fullyQualifiedSiteName" id="@blimmer/cdk-static-wordpress.StaticWordpressProps.property.fullyQualifiedSiteName"></a>

```typescript
public readonly fullyQualifiedSiteName: string;
```

- *Type:* string

The fully qualified site name (e.g., myblog.com or subdomain.myblog.com).

---

##### `hostedZone`<sup>Required</sup> <a name="hostedZone" id="@blimmer/cdk-static-wordpress.StaticWordpressProps.property.hostedZone"></a>

```typescript
public readonly hostedZone: IHostedZone;
```

- *Type:* aws-cdk-lib.aws_route53.IHostedZone

The HostedZone to use to create DNS entries for the site.

---

##### `wordpressAdminProps`<sup>Required</sup> <a name="wordpressAdminProps" id="@blimmer/cdk-static-wordpress.StaticWordpressProps.property.wordpressAdminProps"></a>

```typescript
public readonly wordpressAdminProps: WordpressAdminProps;
```

- *Type:* <a href="#@blimmer/cdk-static-wordpress.WordpressAdminProps">WordpressAdminProps</a>

---

##### `cloudFrontDistributionConfig`<sup>Optional</sup> <a name="cloudFrontDistributionConfig" id="@blimmer/cdk-static-wordpress.StaticWordpressProps.property.cloudFrontDistributionConfig"></a>

```typescript
public readonly cloudFrontDistributionConfig: CloudFrontDistributionConfig;
```

- *Type:* <a href="#@blimmer/cdk-static-wordpress.CloudFrontDistributionConfig">CloudFrontDistributionConfig</a>

---

##### `ecsCluster`<sup>Optional</sup> <a name="ecsCluster" id="@blimmer/cdk-static-wordpress.StaticWordpressProps.property.ecsCluster"></a>

```typescript
public readonly ecsCluster: ICluster;
```

- *Type:* aws-cdk-lib.aws_ecs.ICluster
- *Default:* a new ECS cluster will be created

The ECS cluster for the Wordpress admin site.

---

##### `siteId`<sup>Optional</sup> <a name="siteId" id="@blimmer/cdk-static-wordpress.StaticWordpressProps.property.siteId"></a>

```typescript
public readonly siteId: string;
```

- *Type:* string
- *Default:* the `fullyQualifiedSiteName` will be sanitized and used

An ID to use throughout this construct to identify resources. Any non-word characters will be replaced with dashes.

NOTE: if you intend to change the domain name (via `fullyQualifiedSiteName`), you should set this `siteId` to
a static value. Otherwise, the `siteId` will change when you change the site name.

---

##### `vpc`<sup>Optional</sup> <a name="vpc" id="@blimmer/cdk-static-wordpress.StaticWordpressProps.property.vpc"></a>

```typescript
public readonly vpc: IVpc;
```

- *Type:* aws-cdk-lib.aws_ec2.IVpc
- *Default:* a new VPC will be created

The VPC assigned to the `ecsCluster`.

---

##### `wordpressDatabaseProps`<sup>Optional</sup> <a name="wordpressDatabaseProps" id="@blimmer/cdk-static-wordpress.StaticWordpressProps.property.wordpressDatabaseProps"></a>

```typescript
public readonly wordpressDatabaseProps: WordpressDatabaseProps;
```

- *Type:* <a href="#@blimmer/cdk-static-wordpress.WordpressDatabaseProps">WordpressDatabaseProps</a>

---

##### `wordpressDockerImageProps`<sup>Optional</sup> <a name="wordpressDockerImageProps" id="@blimmer/cdk-static-wordpress.StaticWordpressProps.property.wordpressDockerImageProps"></a>

```typescript
public readonly wordpressDockerImageProps: WordpressDockerImageProps;
```

- *Type:* <a href="#@blimmer/cdk-static-wordpress.WordpressDockerImageProps">WordpressDockerImageProps</a>

---

### WordpressAdminProps <a name="WordpressAdminProps" id="@blimmer/cdk-static-wordpress.WordpressAdminProps"></a>

#### Initializer <a name="Initializer" id="@blimmer/cdk-static-wordpress.WordpressAdminProps.Initializer"></a>

```typescript
import { WordpressAdminProps } from '@blimmer/cdk-static-wordpress'

const wordpressAdminProps: WordpressAdminProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@blimmer/cdk-static-wordpress.WordpressAdminProps.property.email">email</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@blimmer/cdk-static-wordpress.WordpressAdminProps.property.domainPrefix">domainPrefix</a></code> | <code>string</code> | The prefix to use for the non-static admin site. |
| <code><a href="#@blimmer/cdk-static-wordpress.WordpressAdminProps.property.enableEcsExec">enableEcsExec</a></code> | <code>boolean</code> | Enables ECS Exec (https://docs.aws.amazon.com/AmazonECS/latest/developerguide/ecs-exec.html). You can use this to access the container running the Wordpress admin console. |
| <code><a href="#@blimmer/cdk-static-wordpress.WordpressAdminProps.property.password">password</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@blimmer/cdk-static-wordpress.WordpressAdminProps.property.run">run</a></code> | <code>boolean</code> | Should we run the Wordpress admin console? |
| <code><a href="#@blimmer/cdk-static-wordpress.WordpressAdminProps.property.username">username</a></code> | <code>string</code> | *No description.* |

---

##### `email`<sup>Required</sup> <a name="email" id="@blimmer/cdk-static-wordpress.WordpressAdminProps.property.email"></a>

```typescript
public readonly email: string;
```

- *Type:* string

---

##### `domainPrefix`<sup>Optional</sup> <a name="domainPrefix" id="@blimmer/cdk-static-wordpress.WordpressAdminProps.property.domainPrefix"></a>

```typescript
public readonly domainPrefix: string;
```

- *Type:* string
- *Default:* "admin-"

The prefix to use for the non-static admin site.

For example, if your static site is
foo.example.com and you pass `-admin` here, the admin site will be served at admin-foo.example.com.

---

##### `enableEcsExec`<sup>Optional</sup> <a name="enableEcsExec" id="@blimmer/cdk-static-wordpress.WordpressAdminProps.property.enableEcsExec"></a>

```typescript
public readonly enableEcsExec: boolean;
```

- *Type:* boolean
- *Default:* false

Enables ECS Exec (https://docs.aws.amazon.com/AmazonECS/latest/developerguide/ecs-exec.html). You can use this to access the container running the Wordpress admin console.

NOTE: If you enable toggle this flag for an already-running WP Admin site, you'll need to manually stop the
existing task. The ECS service will replace the task with a new one that has ECS Exec enabled. This is a
CloudFormation limitation.

---

##### `password`<sup>Optional</sup> <a name="password" id="@blimmer/cdk-static-wordpress.WordpressAdminProps.property.password"></a>

```typescript
public readonly password: string;
```

- *Type:* string

---

##### `run`<sup>Optional</sup> <a name="run" id="@blimmer/cdk-static-wordpress.WordpressAdminProps.property.run"></a>

```typescript
public readonly run: boolean;
```

- *Type:* boolean
- *Default:* true

Should we run the Wordpress admin console?

Set this to `false` to save money when you're not actively editing
the site.

---

##### `username`<sup>Optional</sup> <a name="username" id="@blimmer/cdk-static-wordpress.WordpressAdminProps.property.username"></a>

```typescript
public readonly username: string;
```

- *Type:* string

---

### WordpressDatabaseProps <a name="WordpressDatabaseProps" id="@blimmer/cdk-static-wordpress.WordpressDatabaseProps"></a>

#### Initializer <a name="Initializer" id="@blimmer/cdk-static-wordpress.WordpressDatabaseProps.Initializer"></a>

```typescript
import { WordpressDatabaseProps } from '@blimmer/cdk-static-wordpress'

const wordpressDatabaseProps: WordpressDatabaseProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@blimmer/cdk-static-wordpress.WordpressDatabaseProps.property.password">password</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@blimmer/cdk-static-wordpress.WordpressDatabaseProps.property.username">username</a></code> | <code>string</code> | *No description.* |

---

##### `password`<sup>Optional</sup> <a name="password" id="@blimmer/cdk-static-wordpress.WordpressDatabaseProps.property.password"></a>

```typescript
public readonly password: string;
```

- *Type:* string

---

##### `username`<sup>Optional</sup> <a name="username" id="@blimmer/cdk-static-wordpress.WordpressDatabaseProps.property.username"></a>

```typescript
public readonly username: string;
```

- *Type:* string

---

### WordpressDockerImageProps <a name="WordpressDockerImageProps" id="@blimmer/cdk-static-wordpress.WordpressDockerImageProps"></a>

#### Initializer <a name="Initializer" id="@blimmer/cdk-static-wordpress.WordpressDockerImageProps.Initializer"></a>

```typescript
import { WordpressDockerImageProps } from '@blimmer/cdk-static-wordpress'

const wordpressDockerImageProps: WordpressDockerImageProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@blimmer/cdk-static-wordpress.WordpressDockerImageProps.property.containerCpu">containerCpu</a></code> | <code>number</code> | The number of vCPU units to give the ECS container at runtime. |
| <code><a href="#@blimmer/cdk-static-wordpress.WordpressDockerImageProps.property.containerMemory">containerMemory</a></code> | <code>number</code> | Memory to give the ECS container at runtime. |
| <code><a href="#@blimmer/cdk-static-wordpress.WordpressDockerImageProps.property.wordpressDockerImageBase">wordpressDockerImageBase</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@blimmer/cdk-static-wordpress.WordpressDockerImageProps.property.wordpressMemoryLimit">wordpressMemoryLimit</a></code> | <code>string</code> | This configures how much memory is given to Wordpress. |
| <code><a href="#@blimmer/cdk-static-wordpress.WordpressDockerImageProps.property.wp2StaticS3AddonVersion">wp2StaticS3AddonVersion</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@blimmer/cdk-static-wordpress.WordpressDockerImageProps.property.wp2StaticVersion">wp2StaticVersion</a></code> | <code>string</code> | The version of wp2static to install. |

---

##### `containerCpu`<sup>Optional</sup> <a name="containerCpu" id="@blimmer/cdk-static-wordpress.WordpressDockerImageProps.property.containerCpu"></a>

```typescript
public readonly containerCpu: number;
```

- *Type:* number
- *Default:* 256 (0.25 vCPU)

The number of vCPU units to give the ECS container at runtime.

See
https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ecs-taskdefinition.html#cfn-ecs-taskdefinition-cpu
for details on available configurations

---

##### `containerMemory`<sup>Optional</sup> <a name="containerMemory" id="@blimmer/cdk-static-wordpress.WordpressDockerImageProps.property.containerMemory"></a>

```typescript
public readonly containerMemory: number;
```

- *Type:* number
- *Default:* 512 (MB)

Memory to give the ECS container at runtime.

See
https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ecs-taskdefinition.html#cfn-ecs-taskdefinition-memory
for details on available configurations

---

##### `wordpressDockerImageBase`<sup>Optional</sup> <a name="wordpressDockerImageBase" id="@blimmer/cdk-static-wordpress.WordpressDockerImageProps.property.wordpressDockerImageBase"></a>

```typescript
public readonly wordpressDockerImageBase: string;
```

- *Type:* string
- *Default:* wordpress:php7.4-apache

---

##### `wordpressMemoryLimit`<sup>Optional</sup> <a name="wordpressMemoryLimit" id="@blimmer/cdk-static-wordpress.WordpressDockerImageProps.property.wordpressMemoryLimit"></a>

```typescript
public readonly wordpressMemoryLimit: string;
```

- *Type:* string
- *Default:* 256M

This configures how much memory is given to Wordpress.

It's different than container memory,
which is configured by `containerMemory`. See
https://developer.wordpress.org/apis/wp-config-php/#increasing-memory-allocated-to-php
for details on this setting.

---

##### `wp2StaticS3AddonVersion`<sup>Optional</sup> <a name="wp2StaticS3AddonVersion" id="@blimmer/cdk-static-wordpress.WordpressDockerImageProps.property.wp2StaticS3AddonVersion"></a>

```typescript
public readonly wp2StaticS3AddonVersion: string;
```

- *Type:* string
- *Default:* 1.0

---

##### `wp2StaticVersion`<sup>Optional</sup> <a name="wp2StaticVersion" id="@blimmer/cdk-static-wordpress.WordpressDockerImageProps.property.wp2StaticVersion"></a>

```typescript
public readonly wp2StaticVersion: string;
```

- *Type:* string
- *Default:* 7.2

The version of wp2static to install.

See
https://github.com/WP2Static/wp2static/releases for available version

---



